
install.packages("ggplot2")

#環境/Setting the worling place
setwd("~/基礎ゼミ2018")

#####################################################################
#基本的な計算/Simple Calculation
#####################################################################


#四則演算/addition, subtraction, multiplication, division
1+1
x<-2*3 #<-で代入できる
x


#ベクトル/Vector
xv<-c(2,3,4,5)　
xv


#行列/Matrix

#作り方１
a<-c(1,2,3,4)
b<-c(5,6,7,8)
xm1<-rbind(a,b)　#row bind(行の結合)
xm1

#作り方２
xm2<-matrix(1:8,nrow=2,ncol=4) 
xm2
xm2[1,2]　#1行2列目の値
xm2[1,]　 #1行目の値


#配列/Array
xa<-array(1:24,dim=c(2,4,3))　#2×4×3の3次元配列
xa[2,3,]
xa[,,1]


#apply関数/apply function
apply(xa,c(1,2),mean)　#行列や配列に使える関数！



#####################################################################
#データの可視化
#####################################################################


#環境/Setting the worling place
setwd("~/基礎ゼミ2018")

#csvファイルの読み込み/Read the csv file
data<-read.csv("movie.csv")


#折れ線グラフ/Line graph
plot(x=(data$year),y=(data$sales),　　　　　　#x,yに使うデータ
     main = "年度別共興収入推移/movie sales",　#タイトル
     xlab="(year)",　　　　　　　　　　　　　　#x軸の名前
     ylab = "(Billion yen)",　　　　　　　　　#y軸の名前
     type="b"　　　　　　　　　　　　　　　　#折れ線と点プロットの組み合わせ
     )

#棒グラフ/Bar graph
barplot((data$sales),
        ylab = "movie sales",　　　　　　#y軸の名前
        col="lightblue",　　　　　　　　　#色も指定できる
        names.arg = (data$title),　　　　#x軸の名前を指定
        cex.names = 0.5,　　　　　　　　#x軸のラベルの文字の大きさ
        las=2　　　　　　　　　　　　　　#x軸のラベルを縦書きに
)

#円グラフ/Pie chart
pie(data$audience,
    main="Movie Audience",　　　　#タイトル
    labels = (data$title),　　　　#ラベルを入れる
    radius=1)　　　　　　　　　　#円の大きさ



#####################################################################
#if文for文/Conditional branch(if) and Repeated attemps(for)
#####################################################################

#if文/
a=2　　　　　　　#aを指定
if(a>0){　　　　#条件
  b<-a+100　　　#当てはまった時
}else{　　　　　#当てはまらなかったとき
  b<-(-100)
}
b               #bを出力


#for文
x<-matrix(1:100,20,5)　　#行列を作る
y<-matrix(0,20,1)　　　　#
 for(i in 1:20){        #繰り返し回数
   y[i]<-max(x[i,])　　#各行の最大値をyに代入
 }
y



#####################################################################
#組み合わせてみた/Application
#####################################################################


#空データの作成/Creating an empty data
evaluation<-matrix(0:0,nrow=18,ncol=1)
#ジブリデータとの結合/ Binding of the movie data
new_data<-cbind(data,evaluation)


for(i in 1:nrow(data)){　　#dataの行数だけ繰り返す　　　　　　　　
  if(data[i,3]>50){　　　　#売り上げが50より大きかった時
    new_data[i,5]<-as.vector("great")　　#great!!
  }else if(data[i,4]>300){  #売り上げはだめでも，人はたくさん来てるとき
    new_data[i,5]<-as.vector("good")     #good!
  }else{                    #それでも
    new_data[i,5]<-as.vector("normal")　#ジブリはいい映画だ．
  }
}


#csvファイルの出力/Write the csv file
write.csv(new_data,"movie_evaluation.csv")


#####################################################################
#パッケージの利用/ Use of the Packages
#####################################################################


#dplyr/ Use of "dplyr" package
library(ggplot2)
library(dplyr)


#csvの読み込み/Read the csv file
data2<-read.csv("okinawa.csv")
siteinfo<-read.csv("siteinfo.csv")

#観光地を3か所に限定/Filtering of tourism spot
data2%>%
  filter((site==35)|(site==36)|(site==37))->data3


#日付別の各観光地の観光人数/The number of tourist per day and per site
data3%>%
  arrange(Observed_Date,site)%>%　　#データの並び替え
  group_by(Observed_Date,site)%>%　　#データのグループ化
  summarise(np=n())->test2　　　　　#集計

#観光地名をつける/Add a tourism sitename
left_join(test2,siteinfo,by="site")->data3　#同じsite番号のところにsitenameを補う



#ggplot /Use of "ggplot" package
library(ggplot2)

g<-ggplot(data3,aes(x=sitename,y=np))+　　　　　#データの指定
  xlab("観光地")+ylab("観光客数")+
  geom_bar(stat="identity",aes(fill=Observed_Date),position = "dodge")　#日付ごとに塗り分けて，同じ施設ずつ横に並べる

plot(g)　#描いてみる
  
ggsave(file="施設ごとの観光客数.png",plot = g)
  

